#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-splice-plugin-2.2.0.0-Emj8zxO6eZUIAI1oB6kInL
key:                  hls-splice-plugin-2.2.0.0-Emj8zxO6eZUIAI1oB6kInL
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5041938afc363ba7108eef45687b2bc2
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.2.0.0-Emj8zxO6eZUIAI1oB6kInL
depends:
    aeson-2.2.1.0-B4RqQZAnAt5HkJbmyrGfNz base-4.18.2.1 containers-0.6.7
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-5wibn5p3dDHK0RAEHmHjOt
    foldl-1.4.18-HE4dW3QYtQcAVamecpZ88k ghc-9.6.6
    ghc-exactprint-1.7.1.0-CBjnhF3qBrE9MmXgU49qmC
    ghcide-2.2.0.0-IfDhKFpXpDyEPTFSn93TjK
    hls-plugin-api-2.2.0.0-AA2o4ovpQUqCXLle9TPcs4
    hls-refactor-plugin-2.2.0.0-2MFKfPmhzd7GMCmxZrCg68
    lens-5.3.3-CrNUPavyVUO9ykk7YePBEi lsp-2.2.0.0-eMvV3FRX9gCFGO6PEmJjh
    mtl-2.3.1 retrie-1.2.3-B8ZjccC1jO45lJRGSnE4GF
    syb-0.7.3-KphnMBwMsN4JTFJbKosoKP text-2.0.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-C4c13QuwLgs7TJHWi6VHCN

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

